@@ -1,3 +1,22 @@
+/*
+ * Licensed to Elasticsearch B.V. under one or more contributor
+ * license agreements. See the NOTICE file distributed with
+ * this work for additional information regarding copyright
+ * ownership. Elasticsearch B.V. licenses this file to you under
+ * the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
 import _ from 'lodash';
 
 function getFieldValues(hits, field) {
@@ -69,11 +88,11 @@ function _groupValues(allValues, params) {
   let k;
 
   allValues.forEach(function (value) {
-    if (_.isObject(value) && !_.isArray(value)) {
+    if (_.isObject(value) && !Array.isArray(value)) {
       throw new Error('Analysis is not available for object fields');
     }
 
-    if (_.isArray(value) && !params.grouped) {
+    if (Array.isArray(value) && !params.grouped) {
       k = value;
     } else {
       k = value == null ? undefined : [value];
