@@ -1,12 +1,31 @@
-import 'plugins/kibana/visualize/saved_visualizations/saved_visualizations';
+/*
+ * Licensed to Elasticsearch B.V. under one or more contributor
+ * license agreements. See the NOTICE file distributed with
+ * this work for additional information regarding copyright
+ * ownership. Elasticsearch B.V. licenses this file to you under
+ * the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
+import '../saved_visualizations/saved_visualizations';
 import 'ui/directives/saved_object_finder';
 import 'ui/directives/paginated_selectable_list';
-import 'plugins/kibana/discover/saved_searches/saved_searches';
+import '../../discover/saved_searches/saved_searches';
 import './wizard.less';
 
 import _ from 'lodash';
-import { VisVisTypeProvider } from 'ui/vis/vis_type';
-import { DashboardConstants } from 'plugins/kibana/dashboard/dashboard_constants';
+import { CATEGORY, CATEGORY_DISPLAY_NAMES } from 'ui/vis/vis_category';
+import { DashboardConstants } from '../../dashboard/dashboard_constants';
 import { VisualizeConstants } from '../visualize_constants';
 import routes from 'ui/routes';
 import { VisTypesRegistryProvider } from 'ui/registry/vis_types';
@@ -14,6 +33,7 @@ import { uiModules } from 'ui/modules';
 import visualizeWizardStep1Template from './step_1.html';
 import visualizeWizardStep2Template from './step_2.html';
 import { SavedObjectsClientProvider } from 'ui/saved_objects';
+import { timefilter } from 'ui/timefilter';
 
 const module = uiModules.get('app/visualize', ['kibana/courier']);
 
@@ -31,34 +51,46 @@ routes.when(VisualizeConstants.WIZARD_STEP_1_PAGE_PATH, {
   controller: 'VisualizeWizardStep1',
 });
 
-module.controller('VisualizeWizardStep1', function ($scope, $route, kbnUrl, timefilter, Private) {
-  timefilter.enabled = false;
-
-  const VisType = Private(VisVisTypeProvider);
-
-  const visTypeCategoryToHumanReadableMap = {
-    [VisType.CATEGORY.BASIC]: 'Basic Charts',
-    [VisType.CATEGORY.DATA]: 'Data',
-    [VisType.CATEGORY.GRAPHIC]: 'Graphic',
-    [VisType.CATEGORY.MAP]: 'Maps',
-    [VisType.CATEGORY.OTHER]: 'Other',
-    [VisType.CATEGORY.TIME]: 'Time Series',
-  };
+module.controller('VisualizeWizardStep1', function ($scope, $route, kbnUrl, Private, config) {
+  timefilter.disableAutoRefreshSelector();
+  timefilter.disableTimeRangeSelector();
 
   const addToDashMode = $route.current.params[DashboardConstants.ADD_VISUALIZATION_TO_DASHBOARD_MODE_PARAM];
   kbnUrl.removeParam(DashboardConstants.ADD_VISUALIZATION_TO_DASHBOARD_MODE_PARAM);
 
   const visTypes = Private(VisTypesRegistryProvider);
+  const isLabsEnabled = config.get('visualize:enableLabs');
+  $scope.toggleLabView = () => {
+    $route.current.params.lab = !$route.current.params.lab;
+    $route.updateParams($route.current.params);
+    $route.reload();
+  };
 
   const categoryToVisTypesMap = {};
 
   visTypes.forEach(visType => {
-    const categoryName = visType.category;
+
+    let categoryName = visType.category;
+
+    if (categoryName === CATEGORY.HIDDEN) {
+      return;
+    }
+
+    if (!isLabsEnabled && visType.stage === 'lab') {
+      return;
+    }
+
+    // If the specified category doesn't have a value in our display names
+    // mapping (most likely because the vis specified a random category, not using
+    // CATEGORY values), just move it to the OTHER category.
+    if (!CATEGORY_DISPLAY_NAMES[categoryName]) {
+      categoryName = CATEGORY.OTHER;
+    }
 
     // Create category object if it doesn't exist yet.
     if (!categoryToVisTypesMap[categoryName]) {
       categoryToVisTypesMap[categoryName] = {
-        label: visTypeCategoryToHumanReadableMap[categoryName],
+        label: CATEGORY_DISPLAY_NAMES[categoryName],
         list: [],
       };
     }
@@ -66,7 +98,6 @@ module.controller('VisualizeWizardStep1', function ($scope, $route, kbnUrl, time
     const categoryVisTypes = categoryToVisTypesMap[categoryName];
 
     // Add the visType to the list and sort them by their title.
-    // categoryVisTypes.list.push(visType);
     categoryVisTypes.list = _.sortBy(
       categoryVisTypes.list.concat(visType),
       type => type.title
@@ -75,7 +106,7 @@ module.controller('VisualizeWizardStep1', function ($scope, $route, kbnUrl, time
 
   // Sort the categories alphabetically.
   const sortedVisTypeCategories = Object.values(categoryToVisTypesMap).sort((a, b) => {
-    const other = VisType.CATEGORY.OTHER.toLowerCase();
+    const other = CATEGORY.OTHER.toLowerCase();
 
     // Put "other" category at the end of the list.
     const labelA = a.label.toLowerCase();
@@ -120,8 +151,19 @@ module.controller('VisualizeWizardStep1', function ($scope, $route, kbnUrl, time
     $scope.filteredVisTypeCategories = getVisTypeCategories();
   });
 
+  $scope.getVisTypeId = type => {
+    return _.camelCase(type.name);
+  };
+
   $scope.getVisTypeTooltip = type => {
-    const prefix = type.isExperimental ? '(Experimental)' : '';
+    //to not clutter the tooltip, just only notify if labs or experimental.
+    //labs is more important in this regard.
+    let prefix = '';
+    if (type.stage === 'lab') {
+      prefix = '(Lab)';
+    } else if (type.stage === 'experimental') {
+      prefix = '(Experimental)';
+    }
     return `${prefix} ${type.description}`;
   };
 
@@ -138,9 +180,9 @@ module.controller('VisualizeWizardStep1', function ($scope, $route, kbnUrl, time
 
   $scope.getVisTypeUrl = function (visType) {
     const baseUrl =
-      visType.requiresSearch
-      ? `#${VisualizeConstants.WIZARD_STEP_2_PAGE_PATH}?`
-      : `#${VisualizeConstants.CREATE_PATH}?`;
+      visType.requiresSearch && visType.options.showIndexSelection
+        ? `#${VisualizeConstants.WIZARD_STEP_2_PAGE_PATH}?`
+        : `#${VisualizeConstants.CREATE_PATH}?`;
 
     const params = [`type=${encodeURIComponent(visType.name)}`];
 
@@ -179,7 +221,7 @@ routes.when(VisualizeConstants.WIZARD_STEP_2_PAGE_PATH, {
   }
 });
 
-module.controller('VisualizeWizardStep2', function ($route, $scope, timefilter, kbnUrl) {
+module.controller('VisualizeWizardStep2', function ($route, $scope, kbnUrl) {
   const type = $route.current.params.type;
   const addToDashMode = $route.current.params[DashboardConstants.ADD_VISUALIZATION_TO_DASHBOARD_MODE_PARAM];
   kbnUrl.removeParam(DashboardConstants.ADD_VISUALIZATION_TO_DASHBOARD_MODE_PARAM);
@@ -200,7 +242,8 @@ module.controller('VisualizeWizardStep2', function ($route, $scope, timefilter,
     );
   };
 
-  timefilter.enabled = false;
+  timefilter.disableAutoRefreshSelector();
+  timefilter.disableTimeRangeSelector();
 
   $scope.indexPattern = {
     selection: null,
