@@ -1,14 +1,34 @@
+/*
+ * Licensed to Elasticsearch B.V. under one or more contributor
+ * license agreements. See the NOTICE file distributed with
+ * this work for additional information regarding copyright
+ * ownership. Elasticsearch B.V. licenses this file to you under
+ * the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
 require('./flot');
 require('plugins/timelion/panels/timechart/timechart.less');
 import _ from 'lodash';
 import $ from 'jquery';
 import moment from 'moment-timezone';
-import observeResize from 'plugins/timelion/lib/observe_resize';
-import calculateInterval from 'plugins/timelion/lib/calculate_interval';
+import observeResize from '../../lib/observe_resize';
+import { calculateInterval, DEFAULT_TIME_FORMAT } from '../../../common/lib';
+import { timefilter } from 'ui/timefilter';
 
-const SET_LEGEND_NUMBERS_DELAY = 50;
+const DEBOUNCE_DELAY = 50;
 
-module.exports = function timechartFn(Private, config, $rootScope, timefilter, $compile) {
+export default function timechartFn(Private, config, $rootScope, $compile) {
   return function () {
     return {
       help: 'Draw a timeseries chart',
@@ -29,11 +49,14 @@ module.exports = function timechartFn(Private, config, $rootScope, timefilter, $
         $scope.search = $scope.search || _.noop;
 
         let legendValueNumbers;
-        const debouncedSetLegendNumbers = _.debounce(setLegendNumbers, SET_LEGEND_NUMBERS_DELAY, {
-          maxWait: SET_LEGEND_NUMBERS_DELAY,
+        let legendCaption;
+        const debouncedSetLegendNumbers = _.debounce(setLegendNumbers, DEBOUNCE_DELAY, {
+          maxWait: DEBOUNCE_DELAY,
           leading: true,
           trailing: false
         });
+        // ensure legend is the same height with or without a caption so legend items do not move around
+        const emptyCaption = '<br>';
 
         const defaultOptions = {
           xaxis: {
@@ -69,7 +92,9 @@ module.exports = function timechartFn(Private, config, $rootScope, timefilter, $
 
               wrapperSpan.setAttribute('class', 'ngLegendValue');
               wrapperSpan.setAttribute('kbn-accessible-click', '');
-              wrapperSpan.setAttribute('ng-click', 'toggleSeries(' + series._id + ')');
+              wrapperSpan.setAttribute('ng-click', `toggleSeries(${series._id})`);
+              wrapperSpan.setAttribute('ng-focus', `focusSeries(${series._id})`);
+              wrapperSpan.setAttribute('ng-mouseover', `highlightSeries(${series._id})`);
 
               labelSpan.setAttribute('ng-non-bindable', '');
               labelSpan.appendChild(document.createTextNode(label));
@@ -84,6 +109,48 @@ module.exports = function timechartFn(Private, config, $rootScope, timefilter, $
           colors: ['#01A4A4', '#C66', '#D0D102', '#616161', '#00A1CB', '#32742C', '#F18D05', '#113F8C', '#61AE24', '#D70060']
         };
 
+        const originalColorMap = new Map();
+        $scope.chart.forEach((series, seriesIndex) => {
+          if (!series.color) {
+            const colorIndex = seriesIndex % defaultOptions.colors.length;
+            series.color = defaultOptions.colors[colorIndex];
+          }
+          originalColorMap.set(series, series.color);
+        });
+
+        let highlightedSeries;
+        let focusedSeries;
+        function unhighlightSeries() {
+          if (highlightedSeries === null) {
+            return;
+          }
+
+          highlightedSeries = null;
+          focusedSeries = null;
+          $scope.chart.forEach((series) => {
+            series.color = originalColorMap.get(series); // reset the colors
+          });
+          drawPlot($scope.chart);
+        }
+        $scope.highlightSeries = _.debounce(function (id) {
+          if (highlightedSeries === id) {
+            return;
+          }
+
+          highlightedSeries = id;
+          $scope.chart.forEach((series, seriesIndex) => {
+            if (seriesIndex !== id) {
+              series.color = 'rgba(128,128,128,0.1)'; // mark as grey
+            } else {
+              series.color = originalColorMap.get(series); // color it like it was
+            }
+          });
+          drawPlot($scope.chart);
+        }, DEBOUNCE_DELAY);
+        $scope.focusSeries = function (id) {
+          focusedSeries = id;
+          $scope.highlightSeries(id);
+        };
 
         $scope.toggleSeries = function (id) {
           const series = $scope.chart[id];
@@ -107,10 +174,11 @@ module.exports = function timechartFn(Private, config, $rootScope, timefilter, $
         });
 
         $elem.on('plotselected', function (event, ranges) {
-          timefilter.time.from = moment(ranges.xaxis.from);
-          timefilter.time.to = moment(ranges.xaxis.to);
-          timefilter.time.mode = 'absolute';
-          $scope.search();
+          timefilter.setTime({
+            from: moment(ranges.xaxis.from),
+            to: moment(ranges.xaxis.to),
+            mode: 'absolute',
+          });
         });
 
         $elem.on('mouseleave', function () {
@@ -131,6 +199,8 @@ module.exports = function timechartFn(Private, config, $rootScope, timefilter, $
 
         // Shamelessly borrowed from the flotCrosshairs example
         function setLegendNumbers(pos) {
+          unhighlightSeries();
+
           const plot = $scope.plot;
 
           const axes = plot.getAxes();
@@ -141,6 +211,9 @@ module.exports = function timechartFn(Private, config, $rootScope, timefilter, $
           let i;
           let j;
           const dataset = plot.getData();
+          if (legendCaption) {
+            legendCaption.text(moment(pos.x).format(_.get(dataset, '[0]._global.legend.timeFormat', DEFAULT_TIME_FORMAT)));
+          }
           for (i = 0; i < dataset.length; ++i) {
 
             const series = dataset[i];
@@ -173,6 +246,9 @@ module.exports = function timechartFn(Private, config, $rootScope, timefilter, $
         }
 
         function clearLegendNumbers() {
+          if (legendCaption) {
+            legendCaption.html(emptyCaption);
+          }
           _.each(legendValueNumbers, function (num) {
             $(num).empty();
           });
@@ -264,7 +340,7 @@ module.exports = function timechartFn(Private, config, $rootScope, timefilter, $
           $scope.plot = $.plot(canvasElem, _.compact(series), options);
 
           if ($scope.plot) {
-            $scope.$emit('renderComplete');
+            $scope.$emit('timelionChartRendered');
           }
 
           legendScope.$destroy();
@@ -274,9 +350,21 @@ module.exports = function timechartFn(Private, config, $rootScope, timefilter, $
           _.each(canvasElem.find('.ngLegendValue'), function (elem) {
             $compile(elem)(legendScope);
           });
+
+          if (_.get($scope.plot.getData(), '[0]._global.legend.showTime', true)) {
+            legendCaption = $('<caption class="timelionLegendCaption"></caption>');
+            legendCaption.html(emptyCaption);
+            canvasElem.find('div.legend table').append(legendCaption);
+
+            // legend has been re-created. Apply focus on legend element when previously set
+            if (focusedSeries || focusedSeries === 0) {
+              const $legendLabels = canvasElem.find('div.legend table .legendLabel>span');
+              $legendLabels.get(focusedSeries).focus();
+            }
+          }
         }
         $scope.$watch('chart', drawPlot);
       }
     };
   };
-};
+}
