@@ -1,3 +1,22 @@
+/*
+ * Licensed to Elasticsearch B.V. under one or more contributor
+ * license agreements. See the NOTICE file distributed with
+ * this work for additional information regarding copyright
+ * ownership. Elasticsearch B.V. licenses this file to you under
+ * the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
 /**
  * @name AppState
  *
@@ -8,19 +27,21 @@
  * ability to destroy those mappings.
  */
 
-import _ from 'lodash';
-import modules from 'ui/modules';
-import StateManagementStateProvider from 'ui/state_management/state';
-import PersistedStatePersistedStateProvider from 'ui/persisted_state/persisted_state';
-let urlParam = '_a';
+import { uiModules } from '../modules';
+import { StateProvider } from './state';
+import '../persisted_state';
+import { createLegacyClass } from '../utils/legacy_class';
+import { callEach } from '../utils/function';
 
-function AppStateProvider(Private, $rootScope, $location) {
-  let State = Private(StateManagementStateProvider);
-  let PersistedState = Private(PersistedStatePersistedStateProvider);
+const urlParam = '_a';
+
+export function AppStateProvider(Private, $rootScope, $location, $injector) {
+  const State = Private(StateProvider);
+  const PersistedState = $injector.get('PersistedState');
   let persistedStates;
   let eventUnsubscribers;
 
-  _.class(AppState).inherits(State);
+  createLegacyClass(AppState).inherits(State);
   function AppState(defaults) {
     // Initialize persistedStates. This object maps "prop" names to
     // PersistedState instances. These are used to make properties "stateful".
@@ -41,7 +62,7 @@ function AppStateProvider(Private, $rootScope, $location) {
   AppState.prototype.destroy = function () {
     AppState.Super.prototype.destroy.call(this);
     AppState.getAppState._set(null);
-    _.callEach(eventUnsubscribers);
+    callEach(eventUnsubscribers);
   };
 
   /**
@@ -49,31 +70,31 @@ function AppStateProvider(Private, $rootScope, $location) {
    */
   AppState.prototype.makeStateful = function (prop) {
     if (persistedStates[prop]) return persistedStates[prop];
-    let self = this;
+    const self = this;
 
     // set up the ui state
     persistedStates[prop] = new PersistedState();
 
     // update the app state when the stateful instance changes
-    let updateOnChange = function () {
-      let replaceState = false; // TODO: debouncing logic
+    const updateOnChange = function () {
+      const replaceState = false; // TODO: debouncing logic
       self[prop] = persistedStates[prop].getChanges();
       // Save state to the URL.
       self.save(replaceState);
     };
-    let handlerOnChange = (method) => persistedStates[prop][method]('change', updateOnChange);
+    const handlerOnChange = (method) => persistedStates[prop][method]('change', updateOnChange);
     handlerOnChange('on');
     eventUnsubscribers.push(() => handlerOnChange('off'));
 
     // update the stateful object when the app state changes
-    let persistOnChange = function (changes) {
+    const persistOnChange = function (changes) {
       if (!changes) return;
 
       if (changes.indexOf(prop) !== -1) {
         persistedStates[prop].set(self[prop]);
       }
     };
-    let handlePersist = (method) => this[method]('fetch_with_changes', persistOnChange);
+    const handlePersist = (method) => this[method]('fetch_with_changes', persistOnChange);
     handlePersist('on');
     eventUnsubscribers.push(() => handlePersist('off'));
 
@@ -92,7 +113,7 @@ function AppStateProvider(Private, $rootScope, $location) {
 
     // Checks to see if the appState might already exist, even if it hasn't been newed up
     get.previouslyStored = function () {
-      let search = $location.search();
+      const search = $location.search();
       return search[urlParam] ? true : false;
     };
 
@@ -106,12 +127,11 @@ function AppStateProvider(Private, $rootScope, $location) {
   return AppState;
 }
 
-modules.get('kibana/global_state')
-.factory('AppState', function (Private) {
-  return Private(AppStateProvider);
-})
-.service('getAppState', function (Private) {
-  return Private(AppStateProvider).getAppState;
-});
+uiModules.get('kibana/global_state')
+  .factory('AppState', function (Private) {
+    return Private(AppStateProvider);
+  })
+  .service('getAppState', function (Private) {
+    return Private(AppStateProvider).getAppState;
+  });
 
-export default AppStateProvider;
