@@ -1,14 +1,50 @@
+/*
+ * Licensed to Elasticsearch B.V. under one or more contributor
+ * license agreements. See the NOTICE file distributed with
+ * this work for additional information regarding copyright
+ * ownership. Elasticsearch B.V. licenses this file to you under
+ * the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
 import _ from 'lodash';
-import 'ui/filters/uriescape';
-import 'ui/filters/rison';
-import uiModules from 'ui/modules';
-import rison from 'rison-node';
-import AppStateProvider from 'ui/state_management/app_state';
+import '../filters/uriescape';
+import '../filters/rison';
+import { uiModules } from '../modules';
+import { AppStateProvider } from '../state_management/app_state';
 
 uiModules.get('kibana/url')
-.service('kbnUrl', function (Private) { return Private(KbnUrlProvider); });
+  .service('kbnUrl', function (Private) { return Private(KbnUrlProvider); });
 
 export function KbnUrlProvider($injector, $location, $rootScope, $parse, Private) {
+  /**
+   *  the `kbnUrl` service was created to smooth over some of the
+   *  inconsistent behavior that occurs when modifying the url via
+   *  the `$location` api. In general it is recommended that you use
+   *  the `kbnUrl` service any time you want to modify the url.
+   *
+   *  "features" that `kbnUrl` does it's best to guarantee, which
+   *  are not guaranteed with the `$location` service:
+   *   - calling `kbnUrl.change()` with a url that resolves to the current
+   *     route will force a full transition (rather than just updating the
+   *     properties of the $route object)
+   *
+   *  Additional features of `kbnUrl`
+   *   - parameterized urls
+   *   - easily include an app state with the url
+   *
+   *  @type {KbnUrl}
+   */
   const self = this;
 
   /**
@@ -71,10 +107,10 @@ export function KbnUrlProvider($injector, $location, $rootScope, $parse, Private
 
     return template.replace(/\{\{([^\}]+)\}\}/g, function (match, expr) {
       // remove filters
-      let key = expr.split('|')[0].trim();
+      const key = expr.split('|')[0].trim();
 
       // verify that the expression can be evaluated
-      let p = $parse(key)(paramObj);
+      const p = $parse(key)(paramObj);
 
       // if evaluation can't be made, throw
       if (_.isUndefined(p)) {
@@ -110,7 +146,7 @@ export function KbnUrlProvider($injector, $location, $rootScope, $parse, Private
    * @return {string} - the computed url
    */
   self.getRouteUrl = function (obj, route) {
-    let template = obj && obj.routes && obj.routes[route];
+    const template = obj && obj.routes && obj.routes[route];
     if (template) return self.eval(template, obj);
   };
 
@@ -138,13 +174,22 @@ export function KbnUrlProvider($injector, $location, $rootScope, $parse, Private
     self.change(self.getRouteUrl(obj, route));
   };
 
+  /**
+   * Removes the given parameter from the url. Does so without modifying the browser
+   * history.
+   * @param param
+   */
+  self.removeParam = function (param) {
+    $location.search(param, null).replace();
+  };
+
   /////
   // private api
   /////
   let reloading;
 
   self._changeLocation = function (type, url, paramObj, replace, appState) {
-    let prev = {
+    const prev = {
       path: $location.path(),
       search: $location.search()
     };
@@ -157,7 +202,7 @@ export function KbnUrlProvider($injector, $location, $rootScope, $parse, Private
       $location.search(appState.getQueryParamName(), appState.toQueryParam());
     }
 
-    let next = {
+    const next = {
       path: $location.path(),
       search: $location.search()
     };
@@ -184,7 +229,7 @@ export function KbnUrlProvider($injector, $location, $rootScope, $parse, Private
   self._shouldForceReload = function (next, prev, $route) {
     if (reloading) return false;
 
-    let route = $route.current && $route.current.$$route;
+    const route = $route.current && $route.current.$$route;
     if (!route) return false;
 
     // for the purposes of determining whether the router will
@@ -193,8 +238,8 @@ export function KbnUrlProvider($injector, $location, $rootScope, $parse, Private
     const prevPath = prev.path || '/';
     if (nextPath !== prevPath) return false;
 
-    let reloadOnSearch = route.reloadOnSearch;
-    let searchSame = _.isEqual(next.search, prev.search);
+    const reloadOnSearch = route.reloadOnSearch;
+    const searchSame = _.isEqual(next.search, prev.search);
     return (reloadOnSearch && searchSame) || !reloadOnSearch;
   };
 }
