@@ -1,3 +1,22 @@
+/*
+ * Licensed to Elasticsearch B.V. under one or more contributor
+ * license agreements. See the NOTICE file distributed with
+ * this work for additional information regarding copyright
+ * ownership. Elasticsearch B.V. licenses this file to you under
+ * the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
 /**
  * @name AggConfig
  *
@@ -6,26 +25,9 @@
  */
 
 import _ from 'lodash';
-import { RegistryFieldFormatsProvider } from 'ui/registry/field_formats';
+import { fieldFormats } from '../registry/field_formats';
 
-export function VisAggConfigProvider(Private, fieldTypeFilter) {
-  const fieldFormats = Private(RegistryFieldFormatsProvider);
-
-  function AggConfig(vis, opts) {
-    const self = this;
-
-    self.id = String(opts.id || AggConfig.nextId(vis.aggs));
-    self.vis = vis;
-    self._opts = opts = (opts || {});
-    self.enabled = typeof opts.enabled === 'boolean' ? opts.enabled : true;
-
-    // setters
-    self.type = opts.type;
-    self.schema = opts.schema;
-
-    // resolve the params
-    self.fillDefaults(opts.params);
-  }
+class AggConfig {
 
   /**
    * Ensure that all of the objects in the list have ids, the objects
@@ -34,7 +36,7 @@ export function VisAggConfigProvider(Private, fieldTypeFilter) {
    * @param  {array[object]} list - a list of objects, objects can be anything really
    * @return {array} - the list that was passed in
    */
-  AggConfig.ensureIds = function (list) {
+  static ensureIds(list) {
     const have = [];
     const haveNot = [];
     list.forEach(function (obj) {
@@ -47,56 +49,38 @@ export function VisAggConfigProvider(Private, fieldTypeFilter) {
     });
 
     return list;
-  };
+  }
 
   /**
    * Calculate the next id based on the ids in this list
    *
    * @return {array} list - a list of objects with id properties
    */
-  AggConfig.nextId = function (list) {
+  static nextId(list) {
     return 1 + list.reduce(function (max, obj) {
       return Math.max(max, +obj.id || 0);
     }, 0);
-  };
+  }
 
-  Object.defineProperties(AggConfig.prototype, {
-    type: {
-      get: function () {
-        return this.__type;
-      },
-      set: function (type) {
-        if (this.__typeDecorations) {
-          _.forOwn(this.__typeDecorations, function (prop, name) {
-            delete this[name];
-          }, this);
-        }
+  constructor(vis, opts = {}, aggs) {
+    this.id = String(opts.id || AggConfig.nextId(vis.aggs));
+    this.vis = vis;
+    this._indexPattern = vis.indexPattern;
+    this._aggs = aggs || vis.aggs;
+    this._opts = opts;
+    this.enabled = typeof opts.enabled === 'boolean' ? opts.enabled : true;
 
-        if (_.isString(type)) {
-          type = AggConfig.aggTypes.byName[type];
-        }
+    // start with empty params so that checks in type/schema setters don't freak
+    // because this.params is undefined
+    this.params = {};
 
-        if (type && _.isFunction(type.decorateAggConfig)) {
-          this.__typeDecorations = type.decorateAggConfig();
-          Object.defineProperties(this, this.__typeDecorations);
-        }
+    // setters
+    this.type = opts.type;
+    this.schema = opts.schema;
 
-        this.__type = type;
-      }
-    },
-    schema: {
-      get: function () {
-        return this.__schema;
-      },
-      set: function (schema) {
-        if (_.isString(schema)) {
-          schema = this.vis.type.schemas.all.byName[schema];
-        }
-
-        this.__schema = schema;
-      }
-    }
-  });
+    // set the params to the values from opts, or just to the defaults
+    this.setParams(opts.params || {});
+  }
 
   /**
    * Write the current values to this.params, filling in the defaults as we go
@@ -105,12 +89,11 @@ export function VisAggConfigProvider(Private, fieldTypeFilter) {
    *                         used when initializing
    * @return {undefined}
    */
-  AggConfig.prototype.fillDefaults = function (from) {
-    const self = this;
-    from = from || self.params || {};
-    const to = self.params = {};
+  setParams(from) {
+    from = from || this.params || {};
+    const to = this.params = {};
 
-    self.getAggParams().forEach(function (aggParam) {
+    this.getAggParams().forEach(aggParam => {
       let val = from[aggParam.name];
 
       if (val == null) {
@@ -119,7 +102,7 @@ export function VisAggConfigProvider(Private, fieldTypeFilter) {
         if (!_.isFunction(aggParam.default)) {
           val = aggParam.default;
         } else {
-          val = aggParam.default(self);
+          val = aggParam.default(this);
           if (val == null) return;
         }
       }
@@ -132,7 +115,7 @@ export function VisAggConfigProvider(Private, fieldTypeFilter) {
         const isDeserialized = (isType || isObject);
 
         if (!isDeserialized) {
-          val = aggParam.deserialize(val, self);
+          val = aggParam.deserialize(val, this);
         }
 
         to[aggParam.name] = val;
@@ -141,81 +124,62 @@ export function VisAggConfigProvider(Private, fieldTypeFilter) {
 
       to[aggParam.name] = _.cloneDeep(val);
     });
-  };
+  }
 
-  /**
-   * Clear the parameters for this aggConfig
-   *
-   * @return {object} the new params object
-   */
-  AggConfig.prototype.resetParams = function () {
-    let field;
-    const fieldOptions = this.getFieldOptions();
+  write(aggs) {
+    return this.type.params.write(this, aggs);
+  }
 
-    if (fieldOptions) {
-      const prevField = fieldOptions.byName[this.fieldName()] || null;
-      let filters = fieldOptions.filterFieldTypes;
-      if (_.isFunction(fieldOptions.filterFieldTypes)) {
-        filters = fieldOptions.filterFieldTypes.bind(this, this.vis);
-      }
-      const fieldOpts = fieldTypeFilter(this.vis.indexPattern.fields, filters);
-      field = _.contains(fieldOpts, prevField) ? prevField : null;
-    }
-
-    return this.fillDefaults({ row: this.params.row, field: field });
-  };
-
-  AggConfig.prototype.write = function () {
-    return this.type.params.write(this);
-  };
-
-  AggConfig.prototype.isFilterable = function () {
+  isFilterable() {
     return _.isFunction(this.type.createFilter);
-  };
+  }
 
-  AggConfig.prototype.createFilter = function (key) {
+  createFilter(key, params = {}) {
     if (!this.isFilterable()) {
-      throw new TypeError('The "' + this.type.title + '" aggregation does not support filtering.');
+      throw new TypeError(`The "${this.type.title}" aggregation does not support filtering.`);
     }
 
     const field = this.getField();
     const label = this.getFieldDisplayName();
     if (field && !field.filterable) {
-      let message = 'The "' + label + '" field can not be used for filtering.';
+      let message = `The "${label}" field can not be used for filtering.`;
       if (field.scripted) {
-        message = 'The "' + label + '" field is scripted and can not be used for filtering.';
+        message = `The "${label}" field is scripted and can not be used for filtering.`;
       }
       throw new TypeError(message);
     }
 
-    return this.type.createFilter(this, key);
-  };
+    return this.type.createFilter(this, key, params);
+  }
 
   /**
-   * Hook into param onRequest handling, and tell the aggConfig that it
-   * is being sent to elasticsearch.
-   *
-   * @return {[type]} [description]
+   *  Hook for pre-flight logic, see AggType#onSearchRequestStart
+   *  @param {Courier.SearchSource} searchSource
+   *  @param {Courier.SearchRequest} searchRequest
+   *  @return {Promise<undefined>}
    */
-  AggConfig.prototype.requesting = function () {
-    const self = this;
-    self.type && self.type.params.forEach(function (param) {
-      if (param.onRequest) param.onRequest(self);
-    });
-  };
+  onSearchRequestStart(searchSource, searchRequest) {
+    if (!this.type) {
+      return Promise.resolve();
+    }
+
+    return Promise.all(
+      this.type.params.map(param => param.modifyAggConfigOnSearchRequestStart(this, searchSource, searchRequest))
+    );
+  }
 
   /**
    * Convert this aggConfig to its dsl syntax.
    *
    * Adds params and adhoc subaggs to a pojo, then returns it
    *
-   * @param  {AggConfig} aggConfig - the config object to convert
+   * @param  {AggConfigs} aggConfigs - the config object to convert
    * @return {void|Object} - if the config has a dsl representation, it is
    *                         returned, else undefined is returned
    */
-  AggConfig.prototype.toDsl = function () {
+  toDsl(aggConfigs) {
     if (this.type.hasNoDsl) return;
-    const output = this.write();
+    const output = this.write(aggConfigs);
 
     const configDsl = {};
     configDsl[this.type.dslName || this.type.name] = output.params;
@@ -225,30 +189,29 @@ export function VisAggConfigProvider(Private, fieldTypeFilter) {
     if (output.subAggs) {
       const subDslLvl = configDsl.aggs || (configDsl.aggs = {});
       output.subAggs.forEach(function nestAdhocSubAggs(subAggConfig) {
-        subDslLvl[subAggConfig.id] = subAggConfig.toDsl();
+        subDslLvl[subAggConfig.id] = subAggConfig.toDsl(aggConfigs);
       });
     }
 
     if (output.parentAggs) {
       const subDslLvl = configDsl.parentAggs || (configDsl.parentAggs = {});
       output.parentAggs.forEach(function nestAdhocSubAggs(subAggConfig) {
-        subDslLvl[subAggConfig.id] = subAggConfig.toDsl();
+        subDslLvl[subAggConfig.id] = subAggConfig.toDsl(aggConfigs);
       });
     }
 
     return configDsl;
-  };
+  }
 
-  AggConfig.prototype.toJSON = function () {
-    const self = this;
-    const params = self.params;
+  toJSON() {
+    const params = this.params;
 
-    const outParams = _.transform(self.getAggParams(), function (out, aggParam) {
+    const outParams = _.transform(this.getAggParams(), (out, aggParam) => {
       let val = params[aggParam.name];
 
       // don't serialize undefined/null values
       if (val == null) return;
-      if (aggParam.serialize) val = aggParam.serialize(val, self);
+      if (aggParam.serialize) val = aggParam.serialize(val, this);
       if (val == null) return;
 
       // to prevent accidental leaking, we will clone all complex values
@@ -256,49 +219,49 @@ export function VisAggConfigProvider(Private, fieldTypeFilter) {
     }, {});
 
     return {
-      id: self.id,
-      enabled: self.enabled,
-      type: self.type && self.type.name,
-      schema: self.schema && self.schema.name,
+      id: this.id,
+      enabled: this.enabled,
+      type: this.type && this.type.name,
+      schema: this.schema && this.schema.name,
       params: outParams
     };
-  };
+  }
 
-  AggConfig.prototype.getAggParams = function () {
-    return [].concat(
-      (this.type) ? this.type.params.raw : [],
-      (this.schema) ? this.schema.params.raw : []
-    );
-  };
+  getAggParams() {
+    return [
+      ...((this.type) ? this.type.params.raw : []),
+      ...((_.has(this, 'schema.params')) ? this.schema.params.raw : []),
+    ];
+  }
 
-  AggConfig.prototype.getRequestAggs = function () {
+  getRequestAggs() {
     if (!this.type) return;
     return this.type.getRequestAggs(this) || [this];
-  };
+  }
 
-  AggConfig.prototype.getResponseAggs = function () {
+  getResponseAggs() {
     if (!this.type) return;
     return this.type.getResponseAggs(this) || [this];
-  };
+  }
 
-  AggConfig.prototype.getValue = function (bucket) {
+  getValue(bucket) {
     return this.type.getValue(this, bucket);
-  };
+  }
 
-  AggConfig.prototype.getKey = function (bucket, key) {
+  getKey(bucket, key) {
     return this.type.getKey(bucket, key, this);
-  };
+  }
 
-  AggConfig.prototype.getFieldDisplayName = function () {
+  getFieldDisplayName() {
     const field = this.getField();
     return field ? (field.displayName || this.fieldName()) : '';
-  };
+  }
 
-  AggConfig.prototype.getField = function () {
+  getField() {
     return this.params.field;
-  };
+  }
 
-  AggConfig.prototype.makeLabel = function () {
+  makeLabel() {
     if (this.params.customLabel) {
       return this.params.customLabel;
     }
@@ -306,13 +269,13 @@ export function VisAggConfigProvider(Private, fieldTypeFilter) {
     if (!this.type) return '';
     let pre = (_.get(this.vis, 'params.mode') === 'percentage') ? 'Percentage of ' : '';
     return pre += this.type.makeLabel(this);
-  };
+  }
 
-  AggConfig.prototype.getIndexPattern = function () {
+  getIndexPattern() {
     return this.vis.indexPattern;
-  };
+  }
 
-  AggConfig.prototype.getFieldOptions = function () {
+  getFieldOptions() {
     const fieldParamType = this.type && this.type.params.byName.field;
 
     if (!fieldParamType || !fieldParamType.getFieldOptions) {
@@ -320,31 +283,77 @@ export function VisAggConfigProvider(Private, fieldTypeFilter) {
     }
 
     return fieldParamType.getFieldOptions(this);
-  };
+  }
 
-  AggConfig.prototype.fieldFormatter = function (contentType, defaultFormat) {
+  fieldFormatter(contentType, defaultFormat) {
     const format = this.type && this.type.getFormat(this);
     if (format) return format.getConverterFor(contentType);
     return this.fieldOwnFormatter(contentType, defaultFormat);
-  };
+  }
 
-  AggConfig.prototype.fieldOwnFormatter = function (contentType, defaultFormat) {
+  fieldOwnFormatter(contentType, defaultFormat) {
     const field = this.getField();
     let format = field && field.format;
     if (!format) format = defaultFormat;
     if (!format) format = fieldFormats.getDefaultInstance('string');
     return format.getConverterFor(contentType);
-  };
+  }
 
-  AggConfig.prototype.fieldName = function () {
+  fieldName() {
     const field = this.getField();
     return field ? field.name : '';
-  };
+  }
 
-  AggConfig.prototype.fieldIsTimeField = function () {
+  fieldIsTimeField() {
     const timeFieldName = this.vis.indexPattern.timeFieldName;
     return timeFieldName && this.fieldName() === timeFieldName;
-  };
+  }
 
-  return AggConfig;
+  get type() {
+    return this.__type;
+  }
+
+  set type(type) {
+    if (this.__typeDecorations) {
+      _.forOwn(this.__typeDecorations, function (prop, name) {
+        delete this[name];
+      }, this);
+    }
+
+    if (_.isString(type)) {
+      // We need to inline require here, since we're having a cyclic dependency
+      // from somewhere inside agg_types back to AggConfig.
+      type = require('../agg_types').aggTypes.byName[type];
+    }
+
+    if (type && _.isFunction(type.decorateAggConfig)) {
+      this.__typeDecorations = type.decorateAggConfig();
+      Object.defineProperties(this, this.__typeDecorations);
+    }
+
+    this.__type = type;
+
+    // clear out the previous params except for a few special ones
+    this.setParams({
+      // split row/columns is "outside" of the agg, so don't reset it
+      row: this.params.row,
+
+      // almost every agg has fields, so we try to persist that when type changes
+      field: _.get(this.getFieldOptions(), ['byName', this.getField()])
+    });
+  }
+
+  get schema() {
+    return this.__schema;
+  }
+
+  set schema(schema) {
+    if (_.isString(schema)) {
+      schema = this.vis.type.schemas.all.byName[schema];
+    }
+
+    this.__schema = schema;
+  }
 }
+
+export { AggConfig };
