@@ -1,10 +1,29 @@
+/*
+ * Licensed to Elasticsearch B.V. under one or more contributor
+ * license agreements. See the NOTICE file distributed with
+ * this work for additional information regarding copyright
+ * ownership. Elasticsearch B.V. licenses this file to you under
+ * the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
 import $ from 'jquery';
 import _ from 'lodash';
-import Binder from 'ui/binder';
-export default function AlertsFactory(Private) {
+
+export function VislibLibAlertsProvider() {
 
   /**
-   * Adds allerts that float in front of a visualization
+   * Adds alerts that float in front of a visualization
    *
    * @class Alerts
    * @constructor
@@ -36,7 +55,7 @@ export default function AlertsFactory(Private) {
       const $closeDiv = $('<div>').addClass('vis-alerts-close').append($closeIcon);
 
       const $alert = $('<div>').addClass('vis-alert vis-alert-' + type).append([$icon, $text, $closeDiv]);
-      $closeDiv.on('click', e => {
+      $closeDiv.on('click', () => {
         $alert.remove();
       });
 
