@@ -1,10 +1,30 @@
+/*
+ * Licensed to Elasticsearch B.V. under one or more contributor
+ * license agreements. See the NOTICE file distributed with
+ * this work for additional information regarding copyright
+ * ownership. Elasticsearch B.V. licenses this file to you under
+ * the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
 import d3 from 'd3';
 import _ from 'lodash';
-import VislibComponentsZeroInjectionInjectZerosProvider from '../components/zero_injection/inject_zeros';
-import VislibComponentsZeroInjectionOrderedXKeysProvider from '../components/zero_injection/ordered_x_keys';
-import VislibComponentsLabelsLabelsProvider from '../components/labels/labels';
-import VislibComponentsColorColorProvider from 'ui/vis/components/color/color';
-export default function DataFactory(Private) {
+import { VislibComponentsZeroInjectionInjectZerosProvider } from '../components/zero_injection/inject_zeros';
+import { VislibComponentsZeroInjectionOrderedXKeysProvider } from '../components/zero_injection/ordered_x_keys';
+import { VislibComponentsLabelsLabelsProvider } from '../components/labels/labels';
+import { VislibComponentsColorColorProvider } from '../../vis/components/color/color';
+
+export function VislibLibDataProvider(Private) {
 
   const injectZeros = Private(VislibComponentsZeroInjectionInjectZerosProvider);
   const orderKeys = Private(VislibComponentsZeroInjectionOrderedXKeysProvider);
@@ -41,6 +61,8 @@ export default function DataFactory(Private) {
             newData[key] = data[key].map(seri => {
               return {
                 label: seri.label,
+                aggLabel: seri.aggLabel,
+                aggId: seri.aggId,
                 values: seri.values.map(val => {
                   const newVal = _.clone(val);
                   newVal.aggConfig = val.aggConfig;
@@ -111,11 +133,7 @@ export default function DataFactory(Private) {
 
     shouldBeStacked(seriesConfig) {
       if (!seriesConfig) return false;
-      const isHistogram = (seriesConfig.type === 'histogram');
-      const isArea = (seriesConfig.type === 'area');
-      const stacked = (seriesConfig.mode === 'stacked');
-
-      return (isHistogram || isArea) && stacked;
+      return (seriesConfig.mode === 'stacked');
     }
 
     getStackedSeries(chartConfig, axis, series, first = false) {
@@ -135,6 +153,7 @@ export default function DataFactory(Private) {
         const id = axis.axisConfig.get('id');
         stackedData[id] = this.getStackedSeries(chartConfig, axis, data, i === 0);
         stackedData[id] = this.injectZeros(stackedData[id], handler.visConfig.get('orderBucketsBySum', false));
+        axis.axisConfig.set('stackedSeries', stackedData[id].length);
         axis.stack(_.map(stackedData[id], 'values'));
       });
       return stackedData;
@@ -279,7 +298,7 @@ export default function DataFactory(Private) {
       const names = [];
       const self = this;
 
-      _.forEach(array, function (obj, i) {
+      _.forEach(array, function (obj) {
         names.push({
           label: obj.name,
           values: obj,
@@ -315,13 +334,13 @@ export default function DataFactory(Private) {
         const namedObj = this.returnNames(slices.children, 0, columns);
 
         return _(namedObj)
-        .sortBy(function (obj) {
-          return obj.index;
-        })
-        .unique(function (d) {
-          return d.label;
-        })
-        .value();
+          .sortBy(function (obj) {
+            return obj.index;
+          })
+          .unique(function (d) {
+            return d.label;
+          })
+          .value();
       }
     }
 
@@ -391,7 +410,7 @@ export default function DataFactory(Private) {
 
     /**
      * Return an array of unique labels
-     * Curently, only used for vertical bar and line charts,
+     * Currently, only used for vertical bar and line charts,
      * or any data object with series values
      *
      * @method getLabels
