@@ -1,15 +1,39 @@
+/*
+ * Licensed to Elasticsearch B.V. under one or more contributor
+ * license agreements. See the NOTICE file distributed with
+ * this work for additional information regarding copyright
+ * ownership. Elasticsearch B.V. licenses this file to you under
+ * the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
 import d3 from 'd3';
 import _ from 'lodash';
-import $ from 'jquery';
-import marked from '../../../../forked/marked';
-import { NoResults } from 'ui/errors';
-import { Binder } from 'ui/binder';
+import MarkdownIt from 'markdown-it';
+import { NoResults } from '../../errors';
+import { Binder } from '../../binder';
 import { VislibLibLayoutLayoutProvider } from './layout/layout';
 import { VislibLibChartTitleProvider } from './chart_title';
 import { VislibLibAlertsProvider } from './alerts';
 import { VislibLibAxisProvider } from './axis/axis';
 import { VislibGridProvider } from './chart_grid';
 import { VislibVisualizationsVisTypesProvider } from '../visualizations/vis_types';
+import { dispatchRenderComplete } from '../../render_complete';
+
+const markdownIt = new MarkdownIt({
+  html: false,
+  linkify: true
+});
 
 export function VisHandlerProvider(Private) {
   const chartTypes = Private(VislibVisualizationsVisTypesProvider);
@@ -62,7 +86,8 @@ export function VisHandlerProvider(Private) {
 
       this.renderArray = this.renderArray
         .concat(this.valueAxes)
-        .concat(this.categoryAxes);
+        // category axes need to render in reverse order https://github.com/elastic/kibana/issues/13551
+        .concat(this.categoryAxes.slice().reverse());
 
       // memoize so that the same function is returned every time,
       // allowing us to remove/re-add the same function
@@ -146,7 +171,7 @@ export function VisHandlerProvider(Private) {
           loadedCount++;
           if (loadedCount === chartSelection.length) {
             // events from all charts are propagated to vis, we only need to fire renderComplete once they all finish
-            $(self.el).trigger('renderComplete');
+            self.vis.emit('renderComplete');
           }
         });
 
@@ -189,25 +214,25 @@ export function VisHandlerProvider(Private) {
       this.removeAll(this.el);
 
       const div = d3.select(this.el)
-      .append('div')
-      // class name needs `chart` in it for the polling checkSize function
-      // to continuously call render on resize
-      .attr('class', 'visualize-error chart error');
+        .append('div')
+        // class name needs `chart` in it for the polling checkSize function
+        // to continuously call render on resize
+        .attr('class', 'visualize-error chart error');
 
       if (message === 'No results found') {
         div.append('div')
-        .attr('class', 'text-center visualize-error visualize-chart')
-        .append('div').attr('class', 'item top')
-        .append('div').attr('class', 'item')
-        .append('h2').html('<i class="fa fa-meh-o"></i>')
-        .append('h4').text(message);
+          .attr('class', 'text-center visualize-error visualize-chart')
+          .append('div').attr('class', 'item top')
+          .append('div').attr('class', 'item')
+          .append('h2').html('<i class="fa fa-meh-o"></i>')
+          .append('h4').text(message);
 
         div.append('div').attr('class', 'item bottom');
       } else {
-        div.append('h4').text(marked.inlineLexer(message, []));
+        div.append('h4').text(markdownIt.renderInline(message));
       }
 
-      $(this.el).trigger('renderComplete');
+      dispatchRenderComplete(this.el);
       return div;
     }
 
