@@ -1,9 +1,29 @@
+/*
+ * Licensed to Elasticsearch B.V. under one or more contributor
+ * license agreements. See the NOTICE file distributed with
+ * this work for additional information regarding copyright
+ * ownership. Elasticsearch B.V. licenses this file to you under
+ * the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
 import d3 from 'd3';
 import _ from 'lodash';
-import dataLabel from 'ui/vislib/lib/_data_label';
-import VislibLibDispatchProvider from '../lib/dispatch';
-import TooltipProvider from 'ui/vis/components/tooltip';
-export default function ChartBaseClass(Private) {
+import { dataLabel } from '../lib/_data_label';
+import { VislibLibDispatchProvider } from '../lib/dispatch';
+import { TooltipProvider } from '../../vis/components/tooltip';
+
+export function VislibVisualizationsChartProvider(Private) {
 
   const Dispatch = Private(VislibLibDispatchProvider);
   const Tooltip = Private(TooltipProvider);
@@ -48,7 +68,7 @@ export default function ChartBaseClass(Private) {
 
       selection.selectAll('*').remove();
       selection.call(this.draw());
-    };
+    }
 
     /**
      * Append the data label to the element
@@ -70,7 +90,7 @@ export default function ChartBaseClass(Private) {
         const label = resolveLabel(datum);
         if (label != null) dataLabel(this, label);
       });
-    };
+    }
 
     /**
      * Removes all DOM elements from the root element
@@ -84,8 +104,8 @@ export default function ChartBaseClass(Private) {
         tooltip.destroy();
       });
       selection.remove();
-    };
+    }
   }
 
   return Chart;
-};
+}
